@@ -480,7 +480,7 @@ def from_dict(
                 raise TypeError(f"Can't initialize {match_!r} with parameters {params!r}: {ex}") from ex
 
     raise TypeError(
-        "Value must be of type `"
+        f"Value '{value}' must be of type `"
         + (
             repr(types[0])
             if len(types) == 1
@@ -488,7 +488,9 @@ def from_dict(
                 (
                     (getattr(e, "__name__", None) or str(e) if e is not type(None) else "None")
                     if _get_origin_cached(e) is not Literal
-                    else repr(e).replace("typing.", "") if e is not None else "None"
+                    else repr(e).replace("typing.", "")
+                    if e is not None
+                    else "None"
                 )
                 for e in types
             )
@@ -645,7 +647,7 @@ def validate_types(expected_types: Union[type, Tuple[type, ...], None], value: A
             continue
 
         if (
-            t is Any  # type: ignore
+            t is Any
             or t is Ellipsis  # type: ignore
             or isinstance(value, origin or t)
             or (
@@ -681,7 +683,7 @@ def validate_types(expected_types: Union[type, Tuple[type, ...], None], value: A
 
                 return []
 
-            if t is Any:  # type: ignore
+            if t is Any:
                 return []
 
             if isinstance(value, origin or t):
